@@ -3,25 +3,18 @@ use strict;
 use warnings;
 use base qw(Module::Install::Base);
 
-our $VERSION = '0.00005';
+our $VERSION = '0.00006';
 
 sub bundle_local_lib {
-    my ($self, @args) = @_;
-
-    my ($class, $lib) = ('App::BundleDeps', 'extlib');
-    if (@args == 1) {
-        $lib = $args[0];
-    } elsif (@args > 1) {
-        ($class, $lib) = @args;
-    }
-
+    my ($self, $lib) = @_;
     $lib ||= 'extlib';
+
     $self->Makefile->postamble(<<EOM);
 bundle_local_lib: metafile
-\t\$(NOECHO) cpanm --skip-installed --local-lib=$lib --installdeps .
+\t\$(NOECHO) bundledeps --extlib=$lib
 
 bundle_local_lib_fast: metafile
-\t\$(NOECHO) cpanm --notest --skip-installed --local-lib=$lib --installdeps .
+\t\$(NOECHO) bundledeps --notest --extlib=$lib
 EOM
 }
 
@@ -66,4 +59,4 @@ under the same terms as Perl itself.
 
 See http://www.perl.com/perl/misc/Artistic.html
 
-=cut
\ No newline at end of file
+=cut
